==> ng-zorro-antd-0.5.0-rc.4.tgz: package/README-zh_CN.md <==
<p align="center">
  <a href="http://ng.ant.design">
    <img width="320" src="https://ng.ant.design/assets/img/zorro.svg">
  </a>
</p>

# NG-ZORRO
[![Build Status](https://travis-ci.org/NG-ZORRO/ng-zorro-antd.svg?branch=master)](https://travis-ci.org/NG-ZORRO/ng-zorro-antd)
[![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)
[![Gitter](https://badges.gitter.im/ng-zorro/ng-zorro-antd.svg)](https://gitter.im/ng-zorro/ng-zorro-antd?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

这里是 Ant Design 的 Angular 4.0 实现，开发和服务于企业级后台产品。

[README in English](README.md)

## 特性

- 提炼自企业级中后台产品的交互语言和视觉风格，定期与Ant Design React版本保持更新一致。
- 开箱即用的高质量 Angular 组件。
- 使用 TypeScript 构建，提供完整的类型定义文件。

## 支持环境

* 现代浏览器和 IE9 以上（需要 [polyfills](https://angular.cn/guide/browser-support)）。

## 兼容版本

当前支持Angular`^4.0.0`版本


## 安装

**我们推荐使用 npm 方式进行开发**，不仅可在开发环境轻松调试，也可放心地在生产环境打包部署使用，享受整个生态圈和工具链带来的诸多好处。

```bash
$ npm install ng-zorro-antd --save
```

如果你的网络环境不佳，推荐使用 [cnpm](https://github.com/cnpm/cnpm)。

## 标准开发

实际项目开发中，你会需要对 TypeScript 代码的构建、调试、代理、打包部署等一系列工程化的需求。
我们推荐官方的 `@angular/cli` 工具链辅助进行开发

如果你想了解更多CLI工具链的功能和命令，建议访问[Angular CLI](https://github.com/angular/angular-cli)了解更多



## 链接

- [首页](http://ng.ant.design)
- [Angular官方文档](https://angular.cn/)
- [开发脚手架](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## 如何贡献

在任何形式的参与前，请先阅读 [贡献者文档](https://github.com/NG-ZORRO/ng-zorro-antd/blob/master/CONTRIBUTING.md)。
如果你希望参与贡献，欢迎 [Pull Request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，或给我们 [报告 Bug](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。

> 强烈推荐阅读 [《提问的智慧》](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way)、[《如何向开源社区提问题》](https://github.com/seajs/seajs/issues/545) 和 [《如何有效地报告 Bug》](http://www.chiark.greenend.org.uk/%7Esgtatham/bugs-cn.html)、[《如何向开源项目提交无法解答的问题》](https://zhuanlan.zhihu.com/p/25795393)，更好的问题更容易获得帮助。

==> ng-zorro-antd-0.6.0-rc.1.tgz: package/README-zh_CN.md <==
<p align="center">
  <a href="http://ng.ant.design">
    <img width="320" src="https://ng.ant.design/assets/img/zorro.svg">
  </a>
</p>

# NG-ZORRO
[![Build Status](https://travis-ci.org/NG-ZORRO/ng-zorro-antd.svg?branch=master)](https://travis-ci.org/NG-ZORRO/ng-zorro-antd)
[![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)
[![Gitter](https://badges.gitter.im/ng-zorro/ng-zorro-antd.svg)](https://gitter.im/ng-zorro/ng-zorro-antd?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)

这里是 Ant Design 的 Angular 4.0 实现，开发和服务于企业级后台产品。

[README in English](README.md)

## 特性

- 提炼自企业级中后台产品的交互语言和视觉风格，定期与Ant Design React版本保持更新一致。
- 开箱即用的高质量 Angular 组件。
- 使用 TypeScript 构建，提供完整的类型定义文件。

## 支持环境

* 现代浏览器和 IE9 以上（需要 [polyfills](https://v2.angular.cn/docs/ts/latest/guide/browser-support.html)）。

## 兼容版本

当前支持Angular`^4.4.4`版本


## 安装

**我们推荐使用 npm 方式进行开发**，不仅可在开发环境轻松调试，也可放心地在生产环境打包部署使用，享受整个生态圈和工具链带来的诸多好处。

```bash
$ npm install ng-zorro-antd --save
```

如果你的网络环境不佳，推荐使用 [cnpm](https://github.com/cnpm/cnpm)。

## 标准开发

实际项目开发中，你会需要对 TypeScript 代码的构建、调试、代理、打包部署等一系列工程化的需求。
我们推荐官方的 `@angular/cli` 工具链辅助进行开发

如果你想了解更多CLI工具链的功能和命令，建议访问[Angular CLI](https://github.com/angular/angular-cli)了解更多



## 链接

- [首页](http://ng.ant.design)
- [Angular官方文档](https://angular.cn/)
- [开发脚手架](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## 如何贡献

在任何形式的参与前，请先阅读 [贡献者文档](https://github.com/NG-ZORRO/ng-zorro-antd/blob/master/CONTRIBUTING.md)。
如果你希望参与贡献，欢迎 [Pull Request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，或给我们 [报告 Bug](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。

> 强烈推荐阅读 [《提问的智慧》](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way)、[《如何向开源社区提问题》](https://github.com/seajs/seajs/issues/545) 和 [《如何有效地报告 Bug》](http://www.chiark.greenend.org.uk/%7Esgtatham/bugs-cn.html)、[《如何向开源项目提交无法解答的问题》](https://zhuanlan.zhihu.com/p/25795393)，更好的问题更容易获得帮助。
